@@ -214,7 +214,7 @@ def test(args):
     saxo_script = sys.modules["__main__"].__file__
     saxo_test_server = os.path.join(saxo.path, "test", "server.py")
 
-    tmp = tempfile.gettempdir()
+    tmp = tempfile.mkdtemp()
     outgoing = queue.Queue()
 
     if not sys.executable:
@@ -279,12 +279,18 @@ def test(args):
     common.thread(run_server)
     common.thread(run_client)
 
+    error = False
+    completed = False
     client_buffer = []
     while True:
         line = outgoing.get()
 
         if line.startswith("S: "):
             print(line)
+            if line.startswith("S: ERROR"):
+               error = True
+            if line.startswith("S: Tests complete"):
+               completed = True
             if not line.startswith("S: Test"):
                 for c in client_buffer:
                     print(c)
@@ -301,6 +307,11 @@ def test(args):
         if line == "Server finished":
             break
 
+    if completed and (not error):
+        sys.exit(0)
+    else:
+        sys.exit(1)
+
 def main(argv, v):
     # NOTE: No default for argv, because what script name would we use?
 
