@@ -121,7 +121,9 @@ def request(url, query=None, data=None, method="GET",
         response["url"] = res.url
         response["status"] = res.status # int
         response["info"] = res.info()
-        response["headers"] = {a.lower(): b for (a, b) in response["info"].items()}
+        response["headers"] = {
+            a.lower(): b for (a, b) in response["info"].items()
+        }
 
         if method == "GET":
             if limit is None:
@@ -129,6 +131,14 @@ def request(url, query=None, data=None, method="GET",
             else:
                 response["octets"] = res.read(limit)
 
+    if "Content-Encoding" in response["info"]:
+        if response["info"]["Content-Encoding"] == "gzip":
+            from gzip import GzipFile
+            from io import BytesIO
+            sio = BytesIO(response["octets"])
+            gz = GzipFile(fileobj=sio)
+            response["octets"] = gz.read()
+
     mime, encoding = content_type(response["info"])
     if mime:
         response["mime"] = mime
@@ -168,7 +178,7 @@ def request(url, query=None, data=None, method="GET",
 
     if mime and ("text" in response):
         if ("/html" in mime) or ("/xhtml" in mime):
-                # TODO: Raw HTML option
+                response["html"] = response["text"]
                 response["text"] = decode_entities(response["text"])
                 response["decoded-entities"] = True
 
